# New in 0.20.0 (2023-01-xx)

## Major changes

-   Model hyperparameter tuning is available through {class}`~scvi.autotune.ModelTuner` (beta) {pr}`1785`,{pr}`1802`,{pr}`1831`.
-   Pre-trained models can now be uploaded to and downloaded from [Hugging Face models] using the {mod}`~scvi.hub`
    module {pr}`1779`,{pr}`1812`,{pr}`1828`,{pr}`1841`, {pr}`1851`.
-   {class}`~anndata.AnnData` `.var` and `.varm` attributes can now be registered through new fields in
    {mod}`~scvi.data.fields` {pr}`1830`,{pr}`1839`.
-   {class}`~scvi.external.SCBASSET`, a reimplementation of the [original scBasset model], is available for
    representation learning of scATAC-seq data (experimental) {pr}`1839`,{pr}`1844`.
-   {class}`~scvi.train.LowLevelPyroTrainingPlan` and {class}`~scvi.model.base.PyroModelGuideWarmup` added to allow the
    use of vanilla PyTorch optimization on Pyro models {pr}`1845`,{pr}`1847`.

## Minor changes

-   Latent mode support changed so that user data is no longer edited in-place {pr}`1756`.
-   Minimum supported PyTorch Lightning version is now 1.8 {pr}`1795`,{pr}`1833`.
-   Minimum supported Python version is now 3.8 {pr}`1819`.
-   [Poetry] removed in favor of [Hatch] for builds and publishing {pr}`1823`.
-   `setup_anndata` docstrings fixed, `setup_mudata` docstrings added {pr}`1834`,{pr}`1837`.
-   {meth}`~scvi.data.add_dna_sequence` adds DNA sequences to {class}`~anndata.AnnData` objects using [genomepy] {pr}`1839`,{pr}`1842`.
-   Update tutorial formatting with pre-commit {pr}`1850`

## Breaking changes

None :)

## Bug Fixes

-   {class}`~scvi.train.JaxTrainingPlan` now correctly updates `global_step` through PyTorch Lightning by using a dummy
    optimizer. {pr}`1791`.
-   CUDA compatibility issue fixed in {meth}`~scvi.distributions.ZeroInflatedNegativeBinomial.sample` {pr}`1813`.
-   Device-backed {class}`~scvi.dataloaders.AnnTorchDataset` fixed to work with sparse data {pr}`1824`.

## Contributors

-   {ghuser}`adamgayoso`
-   {ghuser}`martinkim0`
-   {ghuser}`saroudant`
-   {ghuser}`vitkl`
-   {ghuser}`watiss`
-   {ghuser}`gokceneraslan`
-   {ghuser}`macwiatrak`

[original scbasset model]: https://github.com/calico/scBasset
[poetry]: https://python-poetry.org/
[hatch]: https://hatch.pypa.io/latest/
[genomepy]: https://github.com/vanheeringen-lab/genomepy
[hugging face models]: https://huggingface.co/models
